<?php
namespace Folha\Logic\Cadastros\Evento;

use \Folha\Entities\FpaIncidevento;
use \Folha\Entities\FpaTipoincide;
use \Geral\Util\NovoCodigo;
use \Geral\Util\Ambiente;
use \HCM\Util\DateUtil;
use \Setforms2\Shared\Registry;

class IncidEvento {

    /**
     * Cadastra uma lista de incidências para um evento.
     *
     * @param $nreventom        Evento no qual serão inseridas as incidências.
     * @param $idincidevento    Identificador do tipo de incidência (Não, Soma, Subtrai).
     * @param $listatpincide    Array contendo os tipos de incidência a serem inseridos.
     * @param $dtmescompetenc   Competencia.
     * @param $nrorg            Organização na qual será feita a inserção.
     */
    public function cadastrarListaIncidencias($nreventom, $idincidevento, $listatpincide, $dtmescompetenc, $nrorg)
    {
        if($listatpincide === 'A') {
            /*Insere todos os tipos de incidência*/
            $where = "NRORG = :NRORG OR NRORG = :NRORGPADRAO";
            $params = array(
                'NRORG' => $nrorg,
                'NRORGPADRAO' => \FPA::getNrorgPadrao()
            );
        }
        elseif(is_array($listatpincide)) {
            /*Insere os tipos de incidência selecionados*/
            $lista = "_";
            foreach($listatpincide as $tpincide) {
                $lista .= $tpincide['nrtipoincide']."_";
            }

            $where = "INSTR(:LISTA, NRTIPOINCIDE) > 0 AND (NRORG = :NRORG OR NRORG = :NRORGPADRAO)";
            $params = array(
                'LISTA' => $lista,
                'NRORG' => $nrorg,
                'NRORGPADRAO' => \FPA::getNrorgPadrao()
            );
        }

        $fpatpincidencias = FpaTipoincide::getObjectsByWhere($where, $params);

        self::insereListaTpIncidencia($nreventom, $idincidevento, $fpatpincidencias, $dtmescompetenc, $nrorg);
    }

    private function insereListaTpIncidencia($nreventom, $idincidevento, $tiposincide, $dtmescompetenc, $nrorg)
    {
        try {
            foreach ($tiposincide as $tpincidencia) {

                $fpaIncidEvento = FpaIncidevento::findOneByNreventomAndIdincideventoAndNrtipoincideAndNrorg($nreventom, $idincidevento, $tpincidencia->getNrtipoincide(), $nrorg);

                if (!is_object($fpaIncidEvento)) {
                    $fpaIncidEvento = new FpaIncidevento();

                    $fpaIncidEvento->setNrincidevento(Novocodigo::geraCodigo(Ambiente::getNrorgTrabalho(), 'FPA_INCIDEVENTO', 1, 22, true, false));
                    $fpaIncidEvento->setIdincidevento($idincidevento);
                    $fpaIncidEvento->setNrtipoincide($tpincidencia->getNrtipoincide());
                    $fpaIncidEvento->setNreventom($nreventom);
                    $fpaIncidEvento->setDtmescompetenc(DateUtil::getDataDeString($dtmescompetenc));
                    $fpaIncidEvento->setNrorg($nrorg);
                    $fpaIncidEvento->setNrorginclusao(Ambiente::getNrorgTrabalho());
                    $fpaIncidEvento->setDtinclusao(DateUtil::getDataAtual(true));
                    $fpaIncidEvento->setCdoperinclusao(Ambiente::getCdOperador());
                    $fpaIncidEvento->setNrorgultatu(Ambiente::getNrorgTrabalho());
                    $fpaIncidEvento->setDtultatu(DateUtil::getDataAtual(true));
                    $fpaIncidEvento->setCdoperultatu(Ambiente::getCdOperador());
                    $fpaIncidEvento->persist();
                }
            }

            Registry::getEntityManager()->flush();
        } catch (\Exception $e) {
            throw $e;
        }
    }
}

?>